@@ -8,7 +8,7 @@ from torch_geometric.utils.convert import from_networkx
 from bpemb import BPEmb
 from sentence_transformers import SentenceTransformer
 from graphmanagerlib.Graph import Grapher
-from graphmanagerlib.JsonManager import ConvertJsonToDocumentsObjects, GetJsonFromFile
+from graphmanagerlib.JsonManager import ConvertJsonToDocumentsObjects
 
 bpemb_en = BPEmb(lang="en", dim=100)
 sent_model = SentenceTransformer('distilbert-base-nli-stsb-mean-tokens')
@@ -98,9 +98,9 @@ def makeIndividualData(file):
     print(f'File {file.index} --> Success')
     return individual_data
 
-def getDataForUniquePrediction(jsonPath,saved_prediction_dataset_folder):
+def getDataForUniquePrediction(json,saved_prediction_dataset_folder):
     test_list_of_graphs = []
-    documents = ConvertJsonToDocumentsObjects(jsonPath)[0]
+    documents = ConvertJsonToDocumentsObjects(json)[0]
     individual_data = makeIndividualData(documents)
     test_list_of_graphs.append(individual_data)
     test_data = torch_geometric.data.Batch.from_data_list(test_list_of_graphs)
