@@ -21,8 +21,8 @@ def make_info(document):
     individual_data = from_networkx(G)
     return G, df, individual_data
 
-def predictionsUnique(saved_model_folder,saved_prediction_dataset_folder,document_to_predict_jsonPath,labels_tab):
-    getDataForUniquePrediction(document_to_predict_jsonPath,saved_prediction_dataset_folder)
+def predictionsUnique(saved_model_folder,saved_prediction_dataset_folder,json,labels_tab):
+    getDataForUniquePrediction(json,saved_prediction_dataset_folder)
 
     predictions_data = load_predictionData(save_fd=saved_prediction_dataset_folder)
 
@@ -39,8 +39,7 @@ def predictionsUnique(saved_model_folder,saved_prediction_dataset_folder,documen
     """
     OBTENIR LE DOC EN DOC
     """
-    jsonObject = GetJsonFromFile(document_to_predict_jsonPath);
-    document = ConvertJsonToDocumentsObjects(jsonObject)[0]
+    document = ConvertJsonToDocumentsObjects(json)[0]
     _, df, _ = make_info(document)
 
     assert len(y_pred) == df.shape[0]
